@@ -11,6 +11,11 @@ class ThreadWorker():
     """
 
     def __init__(self, func, name="", on_abort=None, enable_keyboard_interrupt=True):
+        if name:
+            if name in ThreadWorkerManager.allWorkers.keys():
+                name = name+str(ThreadWorkerManager.counts)
+        else:
+            name = 'worker'+str(ThreadWorkerManager.counts)
         self.name = name
         self.id = ThreadWorkerManager.counts
         self.func = None
@@ -28,7 +33,6 @@ class ThreadWorker():
     
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
         self.func = lambda: self.rawfunc(*args, **kwargs)
-        if not self.name: self.name = 'worker'+str(ThreadWorkerManager.counts)
         ThreadWorkerManager.allWorkers[self.name] = self
         ThreadWorkerManager.counts += 1
         self.work()
